@@ -9,10 +9,11 @@ require 'securerandom'
 class GitlabPostReceive
   include NamesHelper
 
-  attr_reader :config, :repo_path, :changes, :jid
+  attr_reader :config, :gl_repository, :repo_path, :changes, :jid
 
-  def initialize(repo_path, actor, changes)
+  def initialize(gl_repository, repo_path, actor, changes)
     @config = GitlabConfig.new
+    @gl_repository = gl_repository
     @repo_path, @actor = repo_path.strip, actor
     @changes = changes
     @jid = SecureRandom.hex(12)
@@ -32,11 +33,11 @@ class GitlabPostReceive
       end
 
       merge_request_urls = GitlabMetrics.measure("merge-request-urls") do
-        api.merge_request_urls(@repo_path, @changes)
+        api.merge_request_urls(@gl_repository, @repo_path, @changes)
       end
       print_merge_request_links(merge_request_urls)
 
-      api.notify_post_receive(repo_path)
+      api.notify_post_receive(gl_repository, repo_path)
     rescue GitlabNet::ApiUnreachableError
       nil
     end
@@ -106,11 +107,14 @@ class GitlabPostReceive
   def update_redis
     # Encode changes as base64 so we don't run into trouble with non-UTF-8 input.
     changes = Base64.encode64(@changes)
+    # TODO: Change to `@gl_repository || @repo_path` in next release.
+    # See https://gitlab.com/gitlab-org/gitlab-shell/merge_requests/130#note_28747613
+    project_identifier = @repo_path
 
     queue = "#{config.redis_namespace}:queue:post_receive"
     msg = JSON.dump({
       'class' => 'PostReceive',
-      'args' => [@repo_path, @actor, changes],
+      'args' => [project_identifier, @actor, changes],
       'jid' => @jid,
       'enqueued_at' => Time.now.to_f
     })
